@@ -1,4 +1,6 @@
 """A service for finding artifacts."""
+from __future__ import annotations
+
 import re
 from enum import Enum
 from typing import Dict, List, NamedTuple, Optional
@@ -72,6 +74,18 @@ class RequestTarget(NamedTuple):
     request_type: RequestType
     identifier: str
 
+    @classmethod
+    def previous_release(cls, identifier: str) -> RequestTarget:
+        """
+        Build a target for either the previous LTS or Continuous release.
+
+        :param identifier: Identifier of release to download.
+        :return: Request target to download given release.
+        """
+        if identifier == BRANCH_FALLBACK:
+            return cls(request_type=RequestType.GIT_BRANCH, identifier=identifier)
+        return cls(request_type=RequestType.MONGO_RELEASE_VERSION, identifier=identifier)
+
     def __str__(self) -> str:
         """Display item as a string."""
         return f"{self.request_type}({self.identifier})"
@@ -141,9 +155,10 @@ class ArtifactDiscoveryService:
                 )
             except MissingBuildVariantError:
                 if mongo_project in NON_VERSION_PROJECTS:
-                    other_project = list(NON_VERSION_PROJECTS.difference(mongo_project))[0]
+                    other_project = find_fallback_project(mongo_project)
                     LOGGER.info(
                         "Could not find expected build variant trying other project",
+                        mongo_project=mongo_project,
                         other_project=other_project,
                     )
                     urls_info = self.scan_for_artifact_urls(
@@ -411,3 +426,19 @@ class ArtifactDiscoveryService:
                 found_versions.append(possible_version_id)
 
         return found_versions
+
+
+def find_fallback_project(searched_project: str) -> str:
+    """
+    Find the other project to try when searching on the master branch.
+
+    :param searched_project: Project that has already been searched.
+    :return: Other project to search.
+    """
+    other_project = list(NON_VERSION_PROJECTS.difference({searched_project}))[0]
+    LOGGER.info(
+        "Could not find expected build variant trying other project",
+        searched_project=searched_project,
+        other_project=other_project,
+    )
+    return other_project
