@@ -208,8 +208,9 @@ class SetupReproOrchestrator:
             multiversionconstants.LAST_LTS_FCV: install_last_lts,
             multiversionconstants.LAST_CONTINUOUS_FCV: install_last_continuous,
         }
+        LOGGER.debug("LTS and continuous release inclusions", releases=releases)
         out = {
-            RequestTarget(RequestType.MONGO_RELEASE_VERSION, version)
+            RequestTarget.previous_release(version)
             for version, requested in releases.items()
             if requested
         }
